Class: Viadeo::Search
- Inherits:
-
GraphConnection
- Object
- GraphObject
- GraphConnection
- Viadeo::Search
- Includes:
- Operations::Get
- Defined in:
- lib/viadeo/search.rb
Overview
List of actions
- retrieve (find, get)
List of connections
- groups (details)[http://dev.viadeo.com/documentation/graph-api-resource/?resource=/search/groups]
- joboffers (details)[http://dev.viadeo.com/documentation/graph-api-resource/?resource=/search/joboffers]
- jobs (details)[http://dev.viadeo.com/documentation/graph-api-resource/?resource=/search/jobs]
- schoolorganization (details)[http://dev.viadeo.com/documentation/graph-api-resource/?resource=/search/schoolorganization]
- users (details)[http://dev.viadeo.com/documentation/graph-api-resource/?resource=/search/users]
Example :
require "viadeo"
Search users at paris school and limit the result to 5
search = Viadeo::Search.new(access_token, connection: "users") search.find(school: "paris", limit: 5)
WARNING: if it called without connection it raise an error
Instance Attribute Summary
Attributes inherited from GraphObject
Method Summary
Methods included from Operations::Get
Methods inherited from GraphConnection
Methods inherited from GraphObject
#[], #[]=, #data_to_graph_object, #each, #initialize, #inspect, #keys, new_from, #refresh_from, #reset, #to_hash, #to_json, #to_s, #updated?, #values
Constructor Details
This class inherits a constructor from Viadeo::GraphConnection
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Viadeo::GraphObject